<?php
/**
 * Theme functions file
 *
 * Contains all of the Theme's setup functions, custom functions,
 * custom hooks and Theme settings.
 * 
 * @package    TheWorld
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2014, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 750; /* pixels */
}

if ( ! function_exists( 'theworld_theme_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * @since  1.0.0
 */
function theworld_theme_setup() {

	// Make the theme available for translation.
	load_theme_textdomain( 'theworld', trailingslashit( get_template_directory() ) . 'languages' );

	// Add custom stylesheet file to the TinyMCE visual editor.
	add_editor_style( array( 'assets/css/editor-style.css', theworld_font_url() ) );

	// Add RSS feed links to <head> for posts and comments.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	// Enable support for Post Thumbnails.
	add_theme_support( 'post-thumbnails' );

	// Declare image sizes.
	add_image_size( 'theworld-carousel', 100, 65, true );
	add_image_size( 'theworld-posts', 200, 200, true );
	add_image_size( 'theworld-widget', 64, 64, true );
	add_image_size( 'theworld-featured', 710, 400, true );
	add_image_size( 'theworld-editors', 200, 135, true );

	// Register custom navigation menu.
	register_nav_menus(
		array(
			'primary'   => __( 'Primary Menu', 'theworld' ),
			'secondary' => __( 'Secondary Menu' , 'theworld' ),
			'tertiary'  => __( 'Footer Menu' , 'theworld' ),
		)
	);

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'comment-list', 'search-form', 'comment-form', 'gallery', 'caption'
	) );

	// Setup the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'theworld_custom_background_args', array(
		'default-color' => 'f0f0f0'
	) ) );

	// Enable theme-layouts extensions.
	add_theme_support( 'theme-layouts', 
		array(
			'1c'   => __( '1 Column Wide (Full Width)', 'theworld' ),
			'2c-l' => __( '2 Columns: Content / Sidebar', 'theworld' ),
			'2c-r' => __( '2 Columns: Sidebar / Content', 'theworld' )
		),
		array( 'customize' => false, 'default' => '2c-l' ) 
	);

	// This theme uses its own gallery styles.
	add_filter( 'use_default_gallery_style', '__return_false' );

}
endif; // theworld_theme_setup
add_action( 'after_setup_theme', 'theworld_theme_setup' );

/**
 * Registers widget areas and custom widgets.
 *
 * @since 1.0.0
 * @link  http://codex.wordpress.org/Function_Reference/register_sidebar
 * @link  http://codex.wordpress.org/Function_Reference/register_widget
 */
function theworld_widgets_init() {

	// Register ad widget.
	require trailingslashit( get_template_directory() ) . 'inc/classes/widget-ads.php';
	register_widget( 'TheWorld_Ads_Widget' );

	// Register feedburner widget.
	require trailingslashit( get_template_directory() ) . 'inc/classes/widget-feedburner.php';
	register_widget( 'TheWorld_Feedburner_Widget' );

	// Register recent posts thumbnail widget.
	require trailingslashit( get_template_directory() ) . 'inc/classes/widget-recent.php';
	register_widget( 'TheWorld_Recent_Widget' );

	// Register popular posts thumbnail widget.
	require trailingslashit( get_template_directory() ) . 'inc/classes/widget-popular.php';
	register_widget( 'TheWorld_Popular_Widget' );

	// Register random posts thumbnail widget.
	require trailingslashit( get_template_directory() ) . 'inc/classes/widget-random.php';
	register_widget( 'TheWorld_Random_Widget' );

	// Register most views posts thumbnail widget.
	require trailingslashit( get_template_directory() ) . 'inc/classes/widget-views.php';
	register_widget( 'TheWorld_Views_Widget' );

	// Register video widget.
	require trailingslashit( get_template_directory() ) . 'inc/classes/widget-video.php';
	register_widget( 'TheWorld_Video_Widget' );

	// Register tabs widget.
	require trailingslashit( get_template_directory() ) . 'inc/classes/widget-tabs.php';
	register_widget( 'TheWorld_Tabs_Widget' );

	register_sidebar(
		array(
			'name'          => __( 'Primary Sidebar', 'theworld' ),
			'id'            => 'primary',
			'description'   => __( 'Main sidebar that appears on the right.', 'theworld' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h1 class="widget-title">',
			'after_title'   => '</h1>',
		)
	);

	register_sidebar(
		array(
			'name'          => __( 'Footer 1', 'theworld' ),
			'id'            => 'footer-1',
			'description'   => __( 'The footer sidebar 1st column.', 'theworld' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		)
	);

	register_sidebar(
		array(
			'name'          => __( 'Footer 2', 'theworld' ),
			'id'            => 'footer-2',
			'description'   => __( 'The footer sidebar 2nd column.', 'theworld' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		)
	);

	register_sidebar(
		array(
			'name'          => __( 'Footer 3', 'theworld' ),
			'id'            => 'footer-3',
			'description'   => __( 'The footer sidebar 3rd column.', 'theworld' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		)
	);

	register_sidebar(
		array(
			'name'          => __( 'Footer 4', 'theworld' ),
			'id'            => 'footer-4',
			'description'   => __( 'The footer sidebar 4th column.', 'theworld' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		)
	);
	
}
add_action( 'widgets_init', 'theworld_widgets_init' );

/**
 * Register Titillium Google font.
 *
 * @since  1.0.0
 * @return string
 */
function theworld_font_url() {
	
	$font_url = '';
	/*
	 * Translators: If there are characters in your language that are not supported
	 * by Titillium, translate this to 'off'. Do not translate into your own language.
	 */
	if ( 'off' !== _x( 'on', 'Titillium font: on or off', 'theworld' ) ) {
		$font_url = add_query_arg( 'family', urlencode( 'Titillium Web:400,300,300italic,400italic,600' ), "//fonts.googleapis.com/css" );
	}

	return $font_url;
}

/**
 * Custom template tags for this theme.
 */
require trailingslashit( get_template_directory() ) . 'inc/template-tags.php';

/**
 * Enqueue scripts and styles.
 */
require trailingslashit( get_template_directory() ) . 'inc/scripts.php';

/**
 * Require and recommended plugins list.
 */
require trailingslashit( get_template_directory() ) . 'inc/plugins.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require trailingslashit( get_template_directory() ) . 'inc/extras.php';

/**
 * Customizer additions.
 */
require trailingslashit( get_template_directory() ) . 'inc/customizer.php';

/**
 * We use some part of Hybrid Core to extends our themes.
 *
 * @link  http://themehybrid.com/hybrid-core Hybrid Core site.
 */
require trailingslashit( get_template_directory() ) . 'inc/hybrid/attr.php';
require trailingslashit( get_template_directory() ) . 'inc/hybrid/loop-pagination.php';
require trailingslashit( get_template_directory() ) . 'inc/hybrid/theme-layouts.php';
require trailingslashit( get_template_directory() ) . 'inc/hybrid/entry-views.php';

/**
 * Load Options Framework core.
 */
define( 'OPTIONS_FRAMEWORK_DIRECTORY', trailingslashit( get_template_directory_uri() ) . 'admin/' );
require trailingslashit( get_template_directory() ) . 'admin/options-framework.php';
require trailingslashit( get_template_directory() ) . 'admin/options-functions.php';

/**
 * Mega menus walker.
 */
require trailingslashit( get_template_directory() ) . 'inc/megamenus/init.php';
require trailingslashit( get_template_directory() ) . 'inc/megamenus/class-theworld-primary-nav-walker.php';

/**
 * Demo importer
 */
require trailingslashit( get_template_directory() ) . 'inc/demo/demo-importer.php';

// MailOptin integration
require get_template_directory() . '/inc/mailoptin.php';
